@@ -8,3 +8,9 @@ from rs_datasets.dating_agency import DatingAgency
 from rs_datasets.book_crossing import BookCrossing
 from rs_datasets.jester import Jester
 from rs_datasets.amazon import Amazon
+from rs_datasets.rekko import Rekko
+from rs_datasets.steam import Steam
+from rs_datasets.anime import Anime
+from rs_datasets.retail_rocket import RetailRocket
+from rs_datasets.youchoose import YooChoose
+from rs_datasets.diginetica import Diginetica
